@@ -7,7 +7,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -24,15 +24,12 @@
 # *  e-mail address 'scipion@cnb.csic.es'
 # *
 # **************************************************************************
-"""
-This module contains constants related to Imagic protocols
-"""
 
 # ------------------ Constants values --------------------------------------
 IMAGIC_HOME = 'IMAGIC_HOME'
 
 # imagic documentation url
-IMAGIC_DOCS = 'http://imagescience.de/imagic.html'
+IMAGIC_DOCS = 'https://imagescience.de/imagic.html'
 
 # MSA distances
 EUCLIDIAN = 0
